Repository<T extends Model> class abstract

Repository

Constructors

Repository()

Properties

allData → LiveData<Map<int, T?>>
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(T data) → bool
get(T? data) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(T? data) → void
toString() → String
A string representation of this object.
inherited
update(T data) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited